@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-## Dilate_Erode.py
+## DilateErode.py
 
 from Watershed import *
 
@@ -11,7 +11,7 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
 
 dilated_image = shed.dilate(5, "square") 
