@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-## Distance_Mapping.py
+## DistanceMapping.py
 
 '''
 This script first shows you a binary image containing several blobs.  You
@@ -8,9 +8,9 @@ are supposed to click inside one of the blobs to place a mark therein.
 Subsequently, the script prints out in the terminal window in which you
 execute the script a distance map with respect to the mark.
 
-If you wish, you can place multiple marks inside a blob by clicking at
-different locations in the blob.  The script will create a distance map
-with respect to all the marks simultanenously.
+The distance map is shown only for the first mark you place inside a blob.
+
+So there is no point to placing multiple marks in one or multiple blobs.
 
 Unless you are using a wide terminal window, you might want to click inside
 one of the smaller blobs in the binary image that shows up.
@@ -34,12 +34,12 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
 shed.connected_components("data")
-shed.mark_blobs()
+shed.mark_blobs('distance_mapping')
 shed.connected_components("marks")
-print "\n\nStart dilating marked blob:\n\n"
+print("\n\nStart dilating marked blob:\n\n")
 shed.dilate_mark_in_its_blob(1)
 
 
