@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-## Edge_Repair.py
+## EdgeRepair.py
 
 '''
 This script demonstrates how small gaps in the boundary of a
@@ -28,7 +28,7 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
 
 dilated_image = shed.dilate(5, "square")                                     
