@@ -28,10 +28,10 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
 shed.connected_components("data")
-shed.mark_blobs()
+shed.mark_blobs('influence_zones')
 shed.connected_components("marks")
 shed.compute_influence_zones_for_marks()
 
