@@ -31,13 +31,13 @@ shed = Watershed(
        )
 
 shed.extract_data_pixels() 
-print "Displaying the original image:"
+print("Displaying the original image:")
 shed.display_data_image()
-print "Calculating the gradient image"
+print("Calculating the gradient image")
 shed.compute_gradient_image()
-print "Computing Z level sets for the gradient image"
+print("Computing Z level sets for the gradient image")
 shed.compute_Z_level_sets_for_gradient_image()
-print "Propagating influences:"
+print("Propagating influences:")
 shed.propagate_influence_zones_from_bottom_to_top_of_Z_levels()
 shed.display_watershed()
 shed.display_watershed_in_color()
